Crate solana_nullable

Crate solana_nullable 

Types for values that can reserve a designated null value.

Structs

MaybeNull
A wrapper that can be used as an Option<T> without requiring extra space to indicate whether the value is Some or None.

Enums

MaybeNullError
Error type for invalid MaybeNull conversions.

Traits

Nullable
Trait for types that can be None.