pub struct MaybeNull<T: Nullable>(/* private fields */);Expand description
A wrapper that can be used as an Option<T> without requiring extra space
to indicate whether the value is Some or None.
This can be used when a specific value of T indicates that its value is
None.
Implementations