Types for values that can reserve a designated null value.
Structs
- Maybe
Null - A wrapper that can be used as an
Option<T>without requiring extra space to indicate whether the value isSomeorNone.
Enums
- Maybe
Null Error - Error type for invalid
MaybeNullconversions.
Traits
- Nullable
- Trait for types that can be
None.