MaybeNull

Struct MaybeNull 

pub struct MaybeNull<T: Nullable>(/* private fields */);
A wrapper that can be used as an Option<T> without requiring extra space to indicate whether the value is Some or None.

This can be used when a specific value of T indicates that its value is None.

Implementations

Source

impl<T: Nullable> MaybeNull<T>

pub fn get(self) -> Option<T>

Returns the contained value as an Option.

pub fn as_ref(&self) -> Option<&T>

Returns a reference to the contained value as an Option.

pub fn as_mut(&mut self) -> Option<&mut T>

Returns a mutable reference to the contained value as an Option.

pub fn copied(&self) -> Option<T>
where T: Copy,

Maps a MaybeNull<T> to an Option<T> by copying the contents of the option.

pub fn cloned(&self) -> Option<T>
where T: Clone,

Maps a MaybeNull<T> to an Option<T> by cloning the contents of the option.